# Cover Rage - server #

[![PyPI version](https://badge.fury.io/py/cover-rage-server.svg)](https://badge.fury.io/py/cover-rage-server) [![CircleCI](https://circleci.com/gh/alexryabtsev/cover_rage_server/tree/master.svg?style=shield)](https://circleci.com/gh/alexryabtsev/cover_rage_server/tree/master)

Server for [cover rage](https://github.com/alexryabtsev/cover_rage).
